@@ -1,6 +1,7 @@
 import click
 from launchable.utils.click import GroupWithAlias
 from .subset import subset
+from .tests import tests
 
 
 @click.group(cls=GroupWithAlias)
@@ -9,3 +10,4 @@ def inspect():
 
 
 inspect.add_command(subset)
+inspect.add_command(tests)
