@@ -1,9 +1,10 @@
+from launchable.commands.record.build import build
 from launchable.utils.authentication import get_org_workspace
-from launchable.utils.session import parse_session
+from launchable.utils.session import parse_session, read_build
 import click
 import os
 import sys
-from os.path import join, relpath, normpath
+from os.path import join, relpath
 import pathlib
 import glob
 from typing import Callable, Union, Optional, List
@@ -55,7 +56,8 @@ from tabulate import tabulate
     'build_name',
     help='build name',
     type=str,
-    metavar='BUILD_NAME'
+    metavar='BUILD_NAME',
+    hidden=True,
 )
 @click.option(
     '--rest',
@@ -94,6 +96,7 @@ from tabulate import tabulate
 @click.pass_context
 def subset(context, target, session: Optional[str], base_path: Optional[str], build_name: Optional[str], rest: str,
            duration, flavor, confidence, split, no_base_path_inference: bool):
+
     session_id = find_or_create_session(context, session, build_name, flavor)
     file_path_normalizer = FilePathNormalizer(
         base_path, no_base_path_inference=no_base_path_inference)
@@ -112,10 +115,10 @@ def subset(context, target, session: Optional[str], base_path: Optional[str], bu
         # output_handler: Callable[[
         #   List[TestPathLike], List[TestPathLike]], None]
 
-        def __init__(self):
+        def __init__(self, dry_run=False):
             self.test_paths = []
             self.output_handler = self._default_output_handler
-            super(Optimize, self).__init__()
+            super(Optimize, self).__init__(dry_run=dry_run)
 
         def _default_output_handler(self, output, rests):
             # regardless of whether we managed to talk to the service we produce
@@ -238,7 +241,8 @@ def subset(context, target, session: Optional[str], base_path: Optional[str], bu
             else:
                 try:
                     client = LaunchableClient(
-                        test_runner=context.invoked_subcommand)
+                        test_runner=context.invoked_subcommand,
+                        dry_run=context.obj.dry_run)
 
                     # temporarily extend the timeout because subset API response has become slow
                     # TODO: remove this line when API response return respose within 60 sec
@@ -301,4 +305,4 @@ def subset(context, target, session: Optional[str], base_path: Optional[str], bu
             click.echo(
                 "\nRun `launchable inspect subset --subset-id {}` to view full subset details".format(subset_id), err=True)
 
-    context.obj = Optimize()
+    context.obj = Optimize(dry_run=context.obj.dry_run)
